<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>falha ao abrir o banco de dados de contas</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>A autorização expirou. Por favor, faça o autentique-se novamente.</translation>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Configurações da Conta</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Por favor, informe o endereço do servidor</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 não é um endereço válido de servidor</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Falhou ao salvar as informações da conta</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Falou ao salvar as modificações: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Atualização com sucesso das informações da conta atual</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Endereço do Servidor</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Falhou ao dessincronizar as bibliotecas desta conta: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>clique para abrir o site</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>Versão Pro</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Sem conta</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Escolha</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Configurações da conta</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Incluir uma conta</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>Não conectado</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation>Falhou ao remover tokens de repositórios locais: %1</translation>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation>Falhou ao obter informações do sincronismo de repositório do servidor: %1</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>De</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <source>server</source>
        <translation>servidor</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation>Atividades de Arquivo são somente suportadas no %1 Servidor Edisão Profissional.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>tentar novamente</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Falhou ao obter informações de atividades. Por favor %1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Envio de arquivo com sucesso</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>Arquivo &quot;%1&quot;
enviado com sucesso.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>Arquivo &quot;%1&quot;
falhou ao enviar.</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Falhou ao criar pasta de avatares</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Tarefas de download</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>todas as tarefas removidas com sucesso</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Sem tarefas de download no momento</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Caminho</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Cancelar esta tarefa</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>cancela esta tarefa</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Remover esta tarefa</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Falha ao cancelar esta tarefa:
%1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Falha ao remover esta tarefa:
%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Bibliotecas</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Estrelado</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Atividades</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>taxa atual de download</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>taxa atual de upload</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Favor escolher uma pasta para sincronizar</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>sem servidor conectado</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>todos os servidores conectados</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>alguns servidores não estão conectados</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimizar</translation>
    </message>
    <message>
        <source>close</source>
        <translation>fechar</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <source>brand</source>
        <translation>marca</translation>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>ou Solte a Pasta aqui para Sincronizar</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>taxa de download</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>downarrow</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>taxa de upload</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>uparrow</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Erro ao criar a configuração ccnet</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Não foi possivel criar um diretorio pré-configurado &quot;%1&quot;</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>falla ao ler %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Criar uma biblioteca</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Por favor escolha uma pasta</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Criando...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation>Falha ao gerar chave de encriptação para essa biblioteca</translation>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Por favor escolha uma pasta para sincronizar</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>A pasta %1 não existe</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Por favor informe o nome</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Por favor informe a senha</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>As senhas não batem</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro deconhecido</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Falha ao incluir a tarefa de download:
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Falhou ao criar biblioteca no servidor:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Caminho:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Escolher</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>encriptado</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Senha de novo:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>texto de status</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>falha ao carregar o diretório de configuração ccnet %1</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation>%1 cliente falhou ao inicializar</translation>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Por favor informe a senha</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Sincronizar biblioteca &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Sincronizar pasta &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Sincronizar para a pasta:</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ou</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>sincronizar com uma pasta existente</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>criar uma nova pasta de sincronização</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Sincronizar com uma pasta existente:</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Por favor, escolha uma pasta</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>A pasta não existe</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Por favor, escolha a pasta para sincronizar.</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>Sua organização desabilitou colocando uma biblioteca fora da 1% pasta.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>Conflito com um arquivo existente &quot;%1&quot;. Por favor, escolha uma pasta diferente.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>Conflito com uma biblioteca existente &quot;%1&quot;. Por favor, escolha uma pasta diferente.</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>A pasta &quot;% 1&quot; já existe. Tem certeza que deseja sincronizar com ele ( os conteúdo serão mesclados ) ?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Clique em Não para sincronizar com  a nova pasta.</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>
Incapaz de encontrar um nome alternativo para a pasta</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Falha ao incluir a tarefa de baixar:
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Falha ao obter informação de descarga do repositório:
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Biblioteca de download</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>escolher...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Senha para esta biblioteca:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Detalhes da Modificação</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Arquivos Adicionados</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Arquivos Apagados</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Arquivos Modificados</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Pastas adicionadas</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Pastas apagadas</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>Abrir pasta &amp;pai</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Navegado de Arquivos na Nuvem</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Início</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Enviar arquivos</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Enviar um diretório</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Você não tem permissões para enviar arquivos para esta biblioteca</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Criar uma pasta</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Nome da pasta</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Nome de pasta inválido!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>O nome &quot;%1&quot; já está sendo utilizado.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>tentar novamente</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Falha ao obter informações dos arquivos&lt;br/&gt;Por favor %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Digite o nome do arquivo para salvar em...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>Não foi possível remover o arquivo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>Digite o caminho da pasta que você deseja salvar em ...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>Você deseja substituir o arquivo existente &quot;% 1&quot;?</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>Arquivo &quot;%1&quot; não foi  sincronizado</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>O arquivo %1 já existe.&lt;br/&gt;Você gostaria de sobrescrever ele?&lt;br/&gt;&lt;small&gt;(Escolha Não para enviar utilizando um nome alternativo)</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Falha ao descarregar o arquivo: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Selecione um arquivo a enviar</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Selecione um diretório para fazer o envio</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Você realmente quer apagar estes itens</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Criação de pasta falhou</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation>Falha ao fechar arquivo</translation>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Selecione um arquivo para enviar %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Renomear falhou</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Remover falhou</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>O compartilhamento falhou</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Não é possível colar arquivos na mesma pasta</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Copiar falhou</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Mover falhou</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Falha ao criar biblioteca!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Enviar arquivo</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Enviando %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarregar</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descarregando %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 de %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Operação cancelada</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>pendente</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Erro Interno do Servidor</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation>Travado por %1</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Última Alteração</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Espécie</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Salvar Como...</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation>&amp;Trancar</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation>Compartilhar com Grupo</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>At&amp;ualizar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>C&amp;olar</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>Canc&amp;elar o Descarregamento</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Sincronizar esta pasta</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Esta característica está disponível somente na versão pro
</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation>&amp;Gerar %1 Link de Download</translation>
    </message>
    <message>
        <source>Share to User</source>
        <translation>Compartilhar com Usuário</translation>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation>G&amp;erar %1 Link interno</translation>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>&amp;Salvar Como...</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation>Des&amp;Travar</translation>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>Não é Possivel remover arquivos somente leitura</translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>Não é possivel recortar arquivos somente leitura</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Falha ao criar pastas</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Falha ao criar arquivos temporários</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Falha ao gravar o arquivo no disco</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Falha ao remover a versão antiga do arquivo descarregado</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Falha ao mover o arquivo</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 inicializado</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation>Escolher %1 pasta</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Por favor escolher uma pasta</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>A inicialização não terminou. Realmente quer sair?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>A pasta %1 não existe</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logotipo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation>Escolher pasta</translation>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation>Por favor, escolha uma pasta. Nos criaremos uma %1 subpasta para ela. Quando você descarregar uma biblioteca, ela será salva lá por padrão.</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Escolher...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Checando sua biblioteca padrão...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Criando biblioteca default...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Falhou ao criar a biblioteca padrão:

A versão do servidor necessita ser 2.1 ou maior para suportar isto.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Falha ao pegar a biblioteca padrão:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Falha ao criar a biblioteca padrão:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Baixando biblioteca default...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Falha ao descarregar a biblioteca padrão:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>A biblioteca padrão foi descarregada.
Você pode clicar no botão &quot;Abrir&quot; para vê-la.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Erro enquanto descarregava a biblioteca padrão: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Falha ao descarregar a biblioteca padrão:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>omitir</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Executar em segundo plano</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Finalizar</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Baixar biblioteca default</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logotipo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Incluir uma conta</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Re-conectar</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Logando em...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Erro de Rede:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt; Aviso: &lt;/ b&gt; O certificado SSL deste servidor não é confiável, continuar assim mesmo?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Favor informar o endereço do servidor</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 não é um endereço do servidor válido</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Por favor informe o nome do usuário</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Por favor, digite o nome do computador</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Falha ao salvar a conta atual</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Autenticação em dois fatores</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Favor informa a senha</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Email ou senha incorreta</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Conectando muito frequentemente, por favor, espere um minuto</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Erro Interno do Servidor</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Falla ao logar: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Falla ao logar</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logotipo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Por exemplo: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>ou http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>texto de status</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Nome do Computador:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>Email / Usuário</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>e.x: Computador do Giba</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation>Deslogue-se Por Favor</translation>
    </message>
    <message>
        <source>login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Adicionar uma conta</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Atualizar</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>falha ao carregar o diretório de configuração ccnet</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>&quot;%1&quot; está dessincronizada.
Razão: Apagada do servidor</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; está sincronizada</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation>Conflito no arquivo %1</translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other user on the server. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>&quot;%1&quot; falhou ao sincronizar.
Acesso negado ao serviço</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>&quot;%1&quot; falha ao sincronizar.
O espaço de armazenamento do dono da biblioteca acabou.</translation>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation>Compatilhar %1</translation>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation>Por favor informe o nome do grupo</translation>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation>Atualizado com sucesso</translation>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Removido com sucesso</translation>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation>Falhou ao obter informação compartilhado da pasta</translation>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation>Falha ao obter informação do seu grupo e contatos</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Por favor informe o nome do usuário</translation>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>sincronizado</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>indexando arquivos</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>incializando sincronismo</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>baixando</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>subindo</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>mesclando</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>esperando sincronismo</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>servidor não conectado</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>autenticando servidor</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>auto sincronismo desligado</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconhecido</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>O Servidor foi removido</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Você não conectou-se ao servidor</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Você não tem permissão para acessar esta biblioteca </translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>O espaço de armazenamento do dono da biblioteca acabou</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Serviço remoto não disponível</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Acesso negado ao serviço.</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Dados internos corrompidos.</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Falha ao iniciar o envio de arquivo</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>Um erro ocorreu durante o envio de arquivo</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>Falha ao iniciar o descarregamento</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>Um erro ocorreu durante o descarregamento</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>A biblioteca está danificada no servidor</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Conflito ao mesclar</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>A versão do servidor é muito antiga</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>A cota de armazenamento foi toda utilizada</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Erro interno do servidor</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>Seu cliente %1 é muito antigo</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Falha ao sincronizar esta biblioteca</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>Os arquivos estão bloqueados por outra aplicação</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>A biblioteca foi removida do servidor</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Erro enquanto acessava a pasta local</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>inicializando...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>conectando ao servidor...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>indexando arquivos...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Criando pasta...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Mesclando arquivos modificados...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Cancelando</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Cancelado</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>Erro de SSL</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erro de Rede: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Erro do Servidor</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>falha ao abrir o banco de dados de certificados</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation>Arquivo &quot;%1&quot; não existe em &quot;%2&quot;</translation>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 não pode encontrar uma aplicação para abrir o arquio %2</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Biblioteca criada &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Biblioteca apagada &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>Renomear %1 para</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>Não foi possível descarregar o item &quot;%1&quot;</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>falha ao copiar</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Adicionado</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Removido</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Renomeado</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Adicionado ou modificado</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Movido</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Diretório adicionado</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Diretório removido</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Diretório renomeado</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Diretório movido</translation>
    </message>
    <message>
        <source>files</source>
        <translation>arquivos</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>diretórios</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>e %1 mais</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Biblioteca revertida para o estado em</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Arquivo revertido &quot;%1&quot; para o estado em %2.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Diretório apagado recuperado</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Nome da biblioteca  ou descrição modificada</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation>Agora</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 dia atrás</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 dias atrás</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 hora atrás</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 horas atrás</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>1 minuto atrás</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minutos atrás</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Não faz parte do certificado&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation>Encontrou outro processo de %1 executando, termina ele e inicia um novo?</translation>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation>Não foi possível iniciar %1 devido a uma falha ao terminar o processo anterior</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation>Sincronizar esta biblioteca com:</translation>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation>Sincronizar esta pasta com:</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Pasta somente leitura</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Documento</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>Documento PDF</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Arquivo de Imagem</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Documento de Texto</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Arquivo de Audio</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Arquivo de Video</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Documento Word</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>Documento PowerPoint</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Documento Excel</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation>O caminhho &quot;%1&quot; conflita com o caminho do sistema</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation>O caminhho &quot;%1&quot; conflita com uma biblioteca existente</translation>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Biblioteca %1</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Esta biblioteca não foi baixada ainda</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Erro:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>Icone do Repo</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>Nome do Repositório</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Dono:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Última Modificação:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Caminho Local:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>Status Repo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechado</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Esta biblioteca não foi baixada</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation>Não foi possível abrir o arquivo &quot;% 1&quot; da biblioteca inexistente &quot;% 2&quot;</translation>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Recentemente Atualizado</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Minhas bibliotecas</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Sub-Bibliotecas</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Bibliotecas sincronizadas</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>inicializando sincronismo</translation>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Desabilitar auto sincronismo</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Habilitar auto sincronismo</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>Exibir &amp;detalhes</translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Exibir detalhes desta biblioteca</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>Sincroni&amp;zar esta biblioteca</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Sincronizar esta biblioteca</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Recentemente Atualizado</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>Si&amp;ncronizar agora</translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Sincronizar esta biblioteca imediatamente</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>&amp;Cancelar download</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Cancelar download desta biblioteca</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;Abrir pasta</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>abrir pasta local</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Desincronizar</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>desincronizar esta biblioteca</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;Ver na nuvem</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>ver esta biblioteca em Seahub</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>Abrir &amp;o navegador de arquivos na nuvem</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>abrir esta biblioteca no Navegador de Arquivos na Nuvem</translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>&amp;Ressincronizar esta biblioteca</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>dessincronizar e ressincronizar esta biblioteca</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Falha ao dessincronizar a biblioteca &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Falha ao cancelar esta tarefa:

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>O download foi cancelado</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation>Não é possível substituir o arquivo &quot;% 1&quot; com ele mesmo</translation>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>Não foi possível apagar o arquivo &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Falha ao enviar o arquivo: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>tentar novamente</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Falha ao buscar informações da biblioteca&lt;br/&gt;Por favor %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt; Aviso: &lt;/ b&gt; O certificado SSL deste servidor não é confiável, continuar assim mesmo?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation>Falha ao adicionar conta padrão</translation>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Falho ao inicializar o histórico: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar para a área de transferência</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>falha ao carregar o diretório de configuração ccnet %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Desabilitar auto sincronismo</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Habilitar auto sincronismo</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Mostrar janela principal</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation>Abrir %1 &amp;Pasta</translation>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation>abrir %1 &amp;pasta</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Abrir pasta de &amp;históricos</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Mostrar caixa de sobre da aplicação</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Ajuda online</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>auto sincronismo está desabilitado</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Enviando</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Descarregando</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>abrir %1 &amp;pasta de log</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>
Abrir % 1 ajuda on-line</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>Alguns servidores não estão conectados</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>retentar</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>Falha na busca&lt;br/&gt;Por favor %1</translation>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Status de conexão dos servidores</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>conectado</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>desconectado</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Por favor, forneça uma senha para a biblioteca</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Forneça uma senha para a biblioteca %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Por favor, digite a senha</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Senha incorreta</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Proxy para Socks5</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Você modificou o idioma. Reiniciar para aplicá-lo?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Ocultar janela principal quando começar</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Notificar quando as bibliotecas estiverem sincronizadas</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Habilitar sincronização de arquivos temporários do MSOffice/LibreOffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Velocidade de descarga (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Velocidade de envio (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Não dessincronizar automaticamente uma biblioteca</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Não dessincronizar automaticamente uma biblioteca quando o diretório local dela é removido ou inacessível por outras razões.</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Não dessincronizar uma biblioteca quando não encontrada no servidor</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Não dessincronizar automaticamente uma biblioteca quando ela não for encontrada no servidor</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>Habilitar a Extensão FinderSync</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Habilitar a Extensão Explorer</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Não verificar o certificado do servidor quando sincronizando por HTTPS</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation>Ativar a sincronização com uma pasta existente com um nome diferente</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Idioma (necessita reiniciar)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Tipo de Proxy:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>O servidor proxy requer uma senha</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Compartilhar Link</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Compartilhar link:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Download direto</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar para a área de transferência</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Conexão não-confiável</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 utiliza um certificado de segurança inválido. A conexão pode ser insegura. Você quer continuar?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>A chave de impressão digital RSA corrente é %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>A chave de impressão digital RSA anterior é  %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Memorizar minha escolha</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Abrir este arquivo</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>exibir na &amp;Web</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>ver este arquivo no site</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>retentar</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Falha ao buscar informações de arquivos estrelados&lt;br/&gt;Por favor %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Você não tem nenhum arquivo estrelado ainda.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Desinstalar %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Você realmente quer remover a informação da conta %1?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Removendo informações da conta...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>text</source>
        <translation>texto</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
</TS>